@@ -8,12 +8,11 @@ Author: Shurui Gui
 
 import argparse
 import subprocess
-import signal
-import sys, os
+import os
 from cilog.api import create_logger, json_mail_setting
 import json
 import shutil
-from definitions import ROOT_DIR
+from cilog.definitions import ROOT_DIR
 
 
 
